@@ -137,6 +137,7 @@ API_PATH = {
     "preferences":             "api/v1/me/prefs",
     "quarantine_opt_in":       "api/quarantine_optin",
     "quarantine_opt_out":      "api/quarantine_optout",
+    "read_all_messages":       "api/read_all_messages",
     "read_message":            "api/read_message/",
     "removal_comment_message": "api/v1/modactions/removal_comment_message",
     "removal_link_message":    "api/v1/modactions/removal_link_message",
@@ -187,6 +188,7 @@ API_PATH = {
     "suggested_sort":          "api/set_suggested_sort/",
     "trophies":                "api/v1/user/{user}/trophies",
     "trusted":                 "prefs/trusted",
+    "unblock_subreddit":       "api/unblock_subreddit",
     "uncollapse":              "api/uncollapse_message/",
     "unfriend":                "r/{subreddit}/api/unfriend/",
     "unhide":                  "api/unhide/",
@@ -198,6 +200,7 @@ API_PATH = {
     "unread_message":          "api/unread_message/",
     "unsave":                  "api/unsave/",
     "unspoiler":               "api/unspoiler/",
+    "update_crowd_control":    "api/update_crowd_control_level",
     "update_settings":         "api/v1/subreddit/update_settings",
     "update_subreddit_rule":   "api/update_subreddit_rule",
     "upload_image":            "r/{subreddit}/api/upload_sr_img",
@@ -215,11 +218,13 @@ API_PATH = {
     "widget_modify":           "r/{subreddit}/api/widget/{widget_id}",
     "widget_order":            "r/{subreddit}/api/widget_order/{section}",
     "widgets":                 "r/{subreddit}/api/widgets",
+    "wiki_discussions":        "r/{subreddit}/wiki/discussions/{page}",
     "wiki_edit":               "r/{subreddit}/api/wiki/edit",
     "wiki_page":               "r/{subreddit}/wiki/{page}",
     "wiki_page_editor":        "r/{subreddit}/api/wiki/alloweditor/{method}",
     "wiki_page_revisions":     "r/{subreddit}/wiki/revisions/{page}",
     "wiki_page_settings":      "r/{subreddit}/wiki/settings/{page}",
     "wiki_pages":              "r/{subreddit}/wiki/pages/",
+    "wiki_revert":             "r/{subreddit}/api/wiki/revert",
     "wiki_revisions":          "r/{subreddit}/wiki/revisions/",
 }
