@@ -6,7 +6,7 @@ from ...exceptions import InvalidURL
 from ..base import PRAWBase
 
 if TYPE_CHECKING:  # pragma: no cover
-    from ... import Reddit
+    import praw
 
 
 class RedditBase(PRAWBase):
@@ -34,27 +34,42 @@ class RedditBase(PRAWBase):
             self._fetch()
             return getattr(self, attribute)
         raise AttributeError(
-            "{!r} object has no attribute {!r}".format(
-                self.__class__.__name__, attribute
-            )
+            f"{self.__class__.__name__!r} object has no attribute {attribute!r}"
         )
 
     def __hash__(self) -> int:
         """Return the hash of the current instance."""
         return hash(self.__class__.__name__) ^ hash(str(self).lower())
 
-    def __init__(self, reddit: "Reddit", _data: Optional[Dict[str, Any]]):
+    def __init__(
+        self,
+        reddit: "praw.Reddit",
+        _data: Optional[Dict[str, Any]],
+        _extra_attribute_to_check: Optional[str] = None,
+        _fetched: bool = False,
+        _str_field: bool = True,
+    ):
         """Initialize a RedditBase instance (or a subclass).
 
         :param reddit: An instance of :class:`~.Reddit`.
 
         """
         super().__init__(reddit, _data=_data)
-        self._fetched = False
+        self._fetched = _fetched
+        if _str_field and self.STR_FIELD not in self.__dict__:
+            if (
+                _extra_attribute_to_check is not None
+                and _extra_attribute_to_check in self.__dict__
+            ):
+                return
+            raise ValueError(
+                f"An invalid value was specified for {self.STR_FIELD}. Check that the "
+                f"argument for the {self.STR_FIELD} parameter is not empty."
+            )
 
     def __repr__(self) -> str:
         """Return an object initialization representation of the instance."""
-        return "{}({}={!r})".format(self.__class__.__name__, self.STR_FIELD, str(self))
+        return f"{self.__class__.__name__}({self.STR_FIELD}={str(self)!r})"
 
     def __str__(self) -> str:
         """Return a string representation of the instance."""
