@@ -5,7 +5,7 @@ from ...const import API_PATH
 from ..base import PRAWBase
 
 if TYPE_CHECKING:  # pragma: no cover
-    from .... import praw
+    import praw
 
 
 class MoreComments(PRAWBase):
